Convenience function to filter enrollment data to a specific Nevada county. Matches on district name containing the county name.
Examples
if (FALSE) { # \dontrun{
# Get Clark County schools
clark <- fetch_enr(2025) |> filter_county("Clark")
} # }
Convenience function to filter enrollment data to a specific Nevada county. Matches on district name containing the county name.
if (FALSE) { # \dontrun{
# Get Clark County schools
clark <- fetch_enr(2025) |> filter_county("Clark")
} # }